Module reply

Module reply 

Reply types and helpers.

Structs

Dns
DNS configuration or settings.
ErrorReply
The reply structure used when returning an error.
Interface
Interface structure for success reply types.
Ip
IP structure for success reply types.
IpamSuccessReply
The reply structure used when returning an abbreviated IPAM success.
Route
Route structure for success reply types.
SuccessReply
The reply structure used when returning a success.
VersionReply
The reply structure used when returning for a VERSION command.

Traits

ReplyPayload
Trait for a reply type to be handled by the reply() function.

Functions

reply
Output the reply as JSON on STDOUT and exit.