Reply types and helpers.
Structs
- Dns
- DNS configuration or settings.
- Error
Reply - The reply structure used when returning an error.
- Interface
- Interface structure for success reply types.
- Ip
- IP structure for success reply types.
- Ipam
Success Reply - The reply structure used when returning an abbreviated IPAM success.
- Route
- Route structure for success reply types.
- Success
Reply - The reply structure used when returning a success.
- Version
Reply - The reply structure used when returning for a
VERSIONcommand.
Traits
- Reply
Payload - Trait for a reply type to be handled by the
reply()function.
Functions
- reply
- Output the reply as JSON on STDOUT and exit.